@@ -26,9 +26,7 @@
 #include <KLocalizedString>
 
 #include <QMimeDatabase>
-#include <QMimeType>
 
-#include "scan.h"
 #include "fsview.h"
 #include "fsviewdebug.h"
 
@@ -404,7 +402,8 @@ QPixmap Inode::pixmap(int i) const
 
     if (!_mimePixmapSet) {
         QUrl u = QUrl::fromLocalFile(path());
-        _mimePixmap = KIconLoader::global()->loadMimeTypeIcon(KIO::iconNameForUrl(u), KIconLoader::Small);
+        const QIcon icon = QIcon::fromTheme(KIO::iconNameForUrl(u), QIcon::fromTheme(QStringLiteral("application-octet-stream")));
+        _mimePixmap = icon.pixmap(KIconLoader::SizeSmall);
         _mimePixmapSet = true;
     }
     return _mimePixmap;
