@@ -29,7 +29,6 @@
 #include "konqdebug.h"
 #include <kio/deletejob.h>
 #include <KLocalizedString>
-#include <QDialog>
 #include <QUrl>
 #include <QIcon>
 #include <ksqueezedtextlabel.h>
@@ -92,7 +91,7 @@ static const QList<KConfigGroup> windowConfigGroups(/*NOT const, we'll use write
 }
 
 SessionRestoreDialog::SessionRestoreDialog(const QStringList &sessionFilePaths, QWidget *parent)
-    : QDialog(parent, nullptr)
+    : QDialog(parent)
     , m_sessionItemsCount(0)
     , m_dontShowChecked(false)
 {
@@ -173,11 +172,7 @@ SessionRestoreDialog::SessionRestoreDialog(const QStringList &sessionFilePaths,
                         item->setData(0, Qt::UserRole, viewIdFor(sessionFile, viewId));
                         item->setFlags(Qt::ItemIsEnabled | Qt::ItemIsUserCheckable);
                         item->setCheckState(0, Qt::Checked);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
                         w = qMax(w, fm.horizontalAdvance(displayText));
-#else
-                        w = qMax(w, fm.width(displayText));
-#endif
                         m_sessionItemsCount++;
                     }
                 }
@@ -361,7 +356,7 @@ bool SessionRestoreDialog::shouldBeShown(const QString &dontShowAgainName, int *
 }
 
 KonqSessionManager::KonqSessionManager()
-    : m_autosaveDir(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + "autosave")
+    : m_autosaveDir(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QLatin1Char('/') + "autosave")
     , m_autosaveEnabled(false) // so that enableAutosave works
     , m_createdOwnedByDir(false)
     , m_sessionConfig(nullptr)
@@ -428,7 +423,7 @@ void KonqSessionManager::enableAutosave()
 
     // Create the config file for autosaving current session
     QString filename = QLatin1String("autosave/") + m_baseService;
-    const QString filePath = QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + filename;
+    const QString filePath = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QLatin1Char('/') + filename;
 
     delete m_sessionConfig;
     m_sessionConfig = new KConfig(filePath, KConfig::SimpleConfig);
